#include <avr/io.h>
#define F_CPU 16000000
#include <stdio.h>
#include <util/delay.h>

/*
 * Functie de initializare a controllerului USART
 */
void USART0_init() 
{
	/* seteaza baud rate la 9600 */
	UBRR0H = 0;
	UBRR0L = 103;

	/* porneste transmisia si receptia */
	UCSR0B = (1<<TXEN0) | (1<<RXEN0);

	/* seteaza formatul frame-ului: 8 biti de date */
	UCSR0C = (3<<UCSZ00);
}


char USART0_receive()
{
	/* asteapta cat timp bufferul e gol */
	while(!(UCSR0A & (1<<RXC0)));

	/* returneaza datele din buffer */
	return UDR0;
}

int main()
{	
	
	DDRD |= (1 << PD6); // Motor 1 Fata
	DDRD |= (1 << PD7); // Motor 1 Spate
	DDRD |= (1 << PD4); // Motor 2 Dreapta
	DDRD |= (1 << PD5); // Motor 2 Stanga
	
	// Initial motoarele sunt pe 0
	PORTD &= ~(1 << PD6);
	PORTD &= ~(1 << PD7);
	PORTD &= ~(1 << PD4);
	PORTD &= ~(1 << PD5);
	
    USART0_init();
	
	int ok = 1;
	char ch;
	
	while(ok) 
	{
		ch = USART0_receive();
		
		if( ch == 'F' )		//Fata
		{
			PORTD &= ~(1 << PD7);
			_delay_ms(100);
			PORTD |= (1 << PD6);
			continue;
		}
		
		
		if( ch == 'G' )		//Fata stanga
		{
			PORTD &= ~(1 << PD7);			
			PORTD &= ~(1 << PD4);

			_delay_ms(100);
			PORTD |= (1 << PD6);
			PORTD |= (1 << PD5);
			continue;
		}
		
		if( ch == 'I' )		//Fata dreapta
		{
			PORTD &= ~(1 << PD7);
			PORTD &= ~(1 << PD5);
			
			_delay_ms(100);
			PORTD |= (1 << PD6);
			PORTD |= (1 << PD4);
			continue;
		}
		
		
		if( ch == 'B' )		//Spate
		{
			PORTD &= ~(1 << PD6);
			_delay_ms(100);
			PORTD |= (1 << PD7);
			continue;
		}
		
		
		if( ch == 'H' )		//Spate stanga
		{
			PORTD &= ~(1 << PD6);
			PORTD &= ~(1 << PD4);
			
			_delay_ms(100);
			PORTD |= (1 << PD7);
			PORTD |= (1 << PD5);
			continue;
		}
		
		
		if( ch == 'J' )		//Spate dreapta
		{
			PORTD &= ~(1 << PD6);			
			PORTD &= ~(1 << PD5);
			
			_delay_ms(100);
			PORTD |= (1 << PD7);
			PORTD |= (1 << PD4);
			continue;
		}
		
		if( ch == 'L' )		//Stanga
		{
			PORTD &= ~(1 << PD4);
			_delay_ms(100);
			PORTD |= (1 << PD5);
			continue;
		}
		
		if( ch == 'R' )		//Dreapta
		{
			PORTD &= ~(1 << PD5);
			_delay_ms(100);
			PORTD |= (1 << PD4);
			continue;
		}
		
		if( ch == 'S' )		//Stop
		{
			PORTD &= ~(1 << PD6);
			PORTD &= ~(1 << PD7);
			PORTD &= ~(1 << PD4);
			PORTD &= ~(1 << PD5);
			continue;
		}
		
		PORTD &= ~(1 << PD6);
		PORTD &= ~(1 << PD7);
		PORTD &= ~(1 << PD4);
		PORTD &= ~(1 << PD5);
		
	}
		
    return 0;
}